| Title: | Outrigger Regression |
|---|---|
| Description: | Performs outrigger local polynomial regression/ distributional adaptation, using a score-matching spline estimator of the conditional score function. Details of the method can be found in Young, Shah and Samworth (2026) <doi:10.48550/arXiv.2603.11282>. |
| Authors: | Elliot H. Young [cre], Rajen D. Shah [aut], Richard J. Samworth [aut] |
| Maintainer: | Elliot H. Young <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.0 |
| Built: | 2026-05-23 08:51:13 UTC |
| Source: | https://github.com/cran/outrigger |
Performs outrigger regression at a point x
outrigger( formula, data, xtest, degree = 0, bandwidth = NULL, kernel = "epan", lambda = NULL, folds = 5, scoregranality = 1, score_df = 10, verbose = TRUE )outrigger( formula, data, xtest, degree = 0, bandwidth = NULL, kernel = "epan", lambda = NULL, folds = 5, scoregranality = 1, score_df = 10, verbose = TRUE )
formula |
formula (as in e.g. |
data |
data frame. |
xtest |
datapoint(s) for local estimation. |
degree |
degree of polynomial. |
bandwidth |
bandwidth parameter. If NULL a rule-of-thumb bandwidth is selected by least-squares cross-validation for the standard local polynomial estimator. |
kernel |
kernel for local polyomial. Default is epanechnikov kernel. |
lambda |
orthogonalisation parameter. By default takes |
folds |
number of folds for cross-fitting. Default is 5. |
scoregranality |
the number of bins to split covariate-space |
score_df |
number of degrees of freedom for score matching splines used for conditional score estimation. Input can be a numeric value (e.g. 10 on larger datasets, 6 on smaller datasets) or "cross-validation" or "cross-validation-quick", in which case score-matching-CV will be performed (may be computationally costly). |
verbose |
suppresses messages of progress. Default is TRUE. |
If x is a single point, return a list containing:
predictionThe outrigger local polynomial estimator at .
fitted_vectorFor the local linear outrigger estimator, the full fitted vector at
standardlocpol_fitted_vectorThe fitted vector for the standard local polynomial
score_plot_metadataData used for score_plotting to plot the fitted conditional score functions
If x is a vector of points, return a dataset with points x and associated outrigger fitted values.
outrigger fit.Plots the fitted score functions learnt in an outrigger fit.
score_plots(fitted_outrig, plot_together = TRUE)score_plots(fitted_outrig, plot_together = TRUE)
fitted_outrig |
a fitted object from |
plot_together |
a logical denoting whether all score function estimators (across all covariate bins) should be plotted toghether. Default is TRUE. |
No return value, called for plotting the estimated score function.